@@ -24,6 +24,7 @@
 #include "../basicindexingjob.h"
 #include "../database.h"
 #include "xapiandatabase.h"
+#include "../tests/util.h"
 
 #include <QDebug>
 #include <QCoreApplication>
@@ -35,7 +36,8 @@
 #include <QSqlError>
 #include <QDBusConnection>
 
-#include <kfilemetadata/propertyinfo.h>
+#include <KFileMetaData/Extractor>
+#include <KFileMetaData/PropertyInfo>
 
 #include <iostream>
 
@@ -43,6 +45,8 @@ using namespace Baloo;
 
 App::App(const QString& path, QObject* parent)
     : QObject(parent)
+    , m_debugEnabled(false)
+    , m_ignoreConfig(false)
     , m_path(path)
     , m_termCount(0)
 {
@@ -51,8 +55,9 @@ App::App(const QString& path, QObject* parent)
         QTimer::singleShot(0, QCoreApplication::instance(), SLOT(quit()));
         return;
     }
+    m_db.sqlDatabase().transaction();
 
-    connect(this, SIGNAL(saved()), this, SLOT(processNextUrl()), Qt::QueuedConnection);
+    connect(this, &App::saved, this, &App::processNextUrl, Qt::QueuedConnection);
 }
 
 void App::startProcessing(const QStringList& args)
@@ -94,7 +99,7 @@ void App::startProcessing(const QStringList& args)
 void App::processNextUrl()
 {
     if (m_urls.isEmpty()) {
-        if (m_results.isEmpty()) {
+        if (m_results.isEmpty() && m_docsToDelete.isEmpty()) {
             QCoreApplication::instance()->exit(0);
         }
         else {
@@ -106,7 +111,7 @@ void App::processNextUrl()
     const QString url = m_urls.takeFirst();
     QString mimetype = m_mimeDb.mimeTypeForFile(url).name();
 
-    if (!m_ignoreConfig) {
+    if (!ignoreConfig()) {
         bool shouldIndex = m_config.shouldBeIndexed(url) && m_config.shouldMimeTypeBeIndexed(mimetype);
         if (!shouldIndex) {
             qDebug() << url << "should not be indexed. Ignoring";
@@ -122,82 +127,59 @@ void App::processNextUrl()
 
     //
     // HACK: We only want to index plain text files which end with a .txt
-    // Also, we're ignoring txt files which are greater tha 50 Mb as we
-    // have trouble processing them
     //
     if (mimetype == QLatin1String("text/plain")) {
-        if (!url.endsWith(".txt")) {
+        if (!url.endsWith(QLatin1String(".txt"))) {
+            qDebug() << "text/plain does not end with .txt. Ignoring";
             mimetype.clear();
         }
+    }
 
+    //
+    // HACK: Also, we're ignoring ttext files which are greater tha 10 Mb as we
+    // have trouble processing them
+    //
+    if (mimetype.startsWith(QStringLiteral("text/"))) {
         QFileInfo fileInfo(url);
-        if (fileInfo.size() >= 50 * 1024 * 1024 ) {
+        if (fileInfo.size() >= 10 * 1024 * 1024 ) {
             mimetype.clear();
         }
     }
 
     FileMapping file(url);
-    if (!m_bData) {
-        if (!file.fetch(m_db.sqlDatabase())) {
-            file.create(m_db.sqlDatabase());
-        }
+    if (!file.fetch(m_db.sqlDatabase())) {
+        file.create(m_db.sqlDatabase());
     }
 
     // We always run the basic indexing again. This is mostly so that the proper
     // mimetype is set and we get proper type information.
     // The mimetype fetched in the BasicIQ is fast but not accurate
-    BasicIndexingJob basicIndexer(&m_db.sqlDatabase(), file, mimetype);
+    BasicIndexingJob basicIndexer(file, mimetype, true /*Indexing Level 2*/);
     basicIndexer.index();
 
     file.setId(basicIndexer.id());
     Xapian::Document doc = basicIndexer.document();
 
-    Result result(url, mimetype);
+    Result result(url, mimetype, KFileMetaData::ExtractionResult::ExtractEverything);
     result.setId(file.id());
     result.setDocument(doc);
-    result.setReadOnly(m_bData);
 
-    QList<KFileMetaData::ExtractorPlugin*> exList = m_manager.fetchExtractors(mimetype);
+    QList<KFileMetaData::Extractor*> exList = m_extractorCollection.fetchExtractors(mimetype);
 
-    Q_FOREACH (KFileMetaData::ExtractorPlugin* plugin, exList) {
-        plugin->extract(&result);
+    Q_FOREACH (KFileMetaData::Extractor* ex, exList) {
+        ex->extract(&result);
     }
     m_results << result;
     m_termCount += result.document().termlist_count();
 
     // Documents with these many terms occupy about 10 mb
-    if (m_termCount >= 10000 && !m_bData) {
+    if (m_termCount >= 10000) {
         saveChanges();
         return;
     }
 
     if (m_urls.isEmpty()) {
-        if (m_bData) {
-            QByteArray arr;
-            QDataStream s(&arr, QIODevice::WriteOnly);
-
-            Q_FOREACH (const Result& res, m_results) {
-                QVariantMap map;
-
-                QMapIterator<QString, QVariant> it(res.map());
-                while (it.hasNext()) {
-                    it.next();
-                    int propNum = it.key().toInt();
-
-                    using namespace KFileMetaData::Property;
-                    Property prop = static_cast<Property>(propNum);
-                    KFileMetaData::PropertyInfo pi(prop);
-                    map.insert(pi.name(), it.value());
-                }
-                s << map;
-            }
-
-            std::cout << arr.toBase64().constData();
-            m_results.clear();
-        }
-        else {
-            saveChanges();
-        }
+        saveChanges();
     }
 
     QTimer::singleShot(0, this, SLOT(processNextUrl()));
@@ -205,13 +187,13 @@ void App::processNextUrl()
 
 void App::saveChanges()
 {
-    if (m_results.isEmpty())
+    if (m_results.isEmpty() && m_docsToDelete.isEmpty())
         return;
 
     m_updatedFiles.clear();
 
     XapianDatabase xapDb(m_path);
-    for (int i = 0; i<m_results.size(); i++) {
+    for (int i = 0; i<m_results.size(); ++i) {
         Result& res = m_results[i];
         res.finish();
 
@@ -222,14 +204,11 @@ void App::saveChanges()
     Q_FOREACH (int docid, m_docsToDelete) {
         xapDb.deleteDocument(docid);
     }
+    m_docsToDelete.clear();
 
     xapDb.commit();
     m_db.sqlDatabase().commit();
 
-    m_results.clear();
-    m_termCount = 0;
-    m_updatedFiles.clear();
-
     QDBusMessage message = QDBusMessage::createSignal(QLatin1String("/files"),
                                                       QLatin1String("org.kde"),
                                                       QLatin1String("changed"));
@@ -241,6 +220,10 @@ void App::saveChanges()
 
     QDBusConnection::sessionBus().send(message);
 
+    m_results.clear();
+    m_termCount = 0;
+    m_updatedFiles.clear();
+
     if (m_debugEnabled) {
         printDebug();
     }
@@ -264,41 +247,10 @@ void App::printDebug()
         }
     }
 
-    // Print the io usage
-    QFile file("/proc/self/io");
-    file.open(QIODevice::ReadOnly | QIODevice::Text);
+    printIOUsage();
+}
 
-    QTextStream fs(&file);
-    QString str = fs.readAll();
-
-    qDebug() << "------- IO ---------";
-    QTextStream stream(&str);
-    while (!stream.atEnd()) {
-        QString str = stream.readLine();
-
-        QString rchar("rchar: ");
-        if (str.startsWith(rchar)) {
-            ulong amt = str.mid(rchar.size()).toULong();
-            qDebug() << "Read:" << amt / 1024  << "kb";
-        }
-
-        QString wchar("wchar: ");
-        if (str.startsWith(wchar)) {
-            ulong amt = str.mid(wchar.size()).toULong();
-            qDebug() << "Write:" << amt / 1024  << "kb";
-        }
-
-        QString read("read_bytes: ");
-        if (str.startsWith(read)) {
-            ulong amt = str.mid(read.size()).toULong();
-            qDebug() << "Actual Reads:" << amt / 1024  << "kb";
-        }
-
-        QString write("write_bytes: ");
-        if (str.startsWith(write)) {
-            ulong amt = str.mid(write.size()).toULong();
-            qDebug() << "Actual Writes:" << amt / 1024  << "kb";
-        }
-    }
-
+bool App::ignoreConfig() const
+{
+    return m_ignoreConfig;
 }
