@@ -27,6 +27,7 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <QDebug>
+#include <QFileInfo>
 #include <iostream>
 
 #include "filewatch.h"
@@ -37,6 +38,7 @@
 
 #include <QDBusConnection>
 #include <QApplication>
+#include <QSessionManager>
 
 int main(int argc, char** argv)
 {
@@ -44,19 +46,24 @@ int main(int argc, char** argv)
     lowerSchedulingPriority();
     lowerPriority();
 
-    KAboutData aboutData("baloo_file", i18n("Baloo File"), "0.1",
+    KAboutData aboutData(QLatin1String("baloo_file"), i18n("Baloo File"), PROJECT_VERSION,
                          i18n("An application to handle file metadata"),
                          KAboutLicense::LGPL_V2);
-    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), "me@vhanda.in", "http://vhanda.in");
+    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QLatin1String("me@vhanda.in"), QLatin1String("http://vhanda.in"));
 
     KAboutData::setApplicationData(aboutData);
 
+    QApplication::setDesktopSettingsAware(false);
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
-    //KUniqueApplication app(true);
-    //app.disableSessionManagement();
 
-    KConfig config("baloofilerc");
+    auto disableSessionManagement = [](QSessionManager &sm) {
+        sm.setRestartHint(QSessionManager::RestartNever);
+    };
+    QObject::connect(&app, &QGuiApplication::commitDataRequest, disableSessionManagement);
+    QObject::connect(&app, &QGuiApplication::saveStateRequest, disableSessionManagement);
+
+    KConfig config(QLatin1String("baloofilerc"));
     KConfigGroup group = config.group("Basic Settings");
     bool indexingEnabled = group.readEntry("Indexing-Enabled", true);
 
@@ -66,7 +73,7 @@ int main(int argc, char** argv)
     }
 
 
-    if (!QDBusConnection::sessionBus().registerService("org.kde.baloo.file")) {
+    if (!QDBusConnection::sessionBus().registerService(QLatin1String("org.kde.baloo"))) {
         qWarning() << "Failed to register via dbus. Another instance is running";
         return 1;
     }
@@ -74,7 +81,7 @@ int main(int argc, char** argv)
     // Crash Handling
     KCrash::setFlags(KCrash::AutoRestart);
 
-    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + "/baloo/file/";
+    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/baloo/file/");
 
     Database db;
     db.setPath(path);
@@ -86,12 +93,10 @@ int main(int argc, char** argv)
 
     Baloo::FileIndexer fileIndexer(&db, &indexerConfig, &app);
 
-    QObject::connect(&filewatcher, SIGNAL(indexFile(QString)),
-                     &fileIndexer, SLOT(indexFile(QString)));
-    QObject::connect(&filewatcher, SIGNAL(installedWatches()),
-                     &fileIndexer, SLOT(update()));
-    QObject::connect(&filewatcher, SIGNAL(fileRemoved(int)),
-                     &fileIndexer, SLOT(removeFileData(int)));
+    QObject::connect(&filewatcher, &Baloo::FileWatch::indexFile, &fileIndexer, &Baloo::FileIndexer::indexFile);
+    QObject::connect(&filewatcher, &Baloo::FileWatch::indexXAttr, &fileIndexer, &Baloo::FileIndexer::indexXAttr);
+    QObject::connect(&filewatcher, &Baloo::FileWatch::installedWatches, &fileIndexer, &Baloo::FileIndexer::update);
+    QObject::connect(&filewatcher, &Baloo::FileWatch::fileRemoved, &fileIndexer, &Baloo::FileIndexer::removeFileData);
 
     return app.exec();
 }
